"""Arabic leaderboard acva light group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.core.contrastive_pairs.lm_eval_pairs.lm_task_extractors."

ARABIC_LEADERBOARD_ACVA_LIGHT_TASKS = {
    "arabic_leaderboard_acva_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Algeria_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Ancient_Egypt_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Arab_Empire_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Arabic_Architecture_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Arabic_Art_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Arabic_Astronomy_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Arabic_Calligraphy_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Arabic_Ceremony_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Arabic_Clothing_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Arabic_Culture_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Arabic_Food_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Arabic_Funeral_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Arabic_Geography_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Arabic_History_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Arabic_Language_Origin_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Arabic_Literature_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Arabic_Math_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Arabic_Medicine_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Arabic_Music_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Arabic_Ornament_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Arabic_Philosophy_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Arabic_Physics_and_Chemistry_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Arabic_Wedding_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Bahrain_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Comoros_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Egypt_modern_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_InfluenceFromAncientEgypt_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_InfluenceFromByzantium_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_InfluenceFromChina_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_InfluenceFromGreece_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_InfluenceFromIslam_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_InfluenceFromPersia_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_InfluenceFromRome_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Iraq_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Islam_Education_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Islam_branches_and_schools_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Islamic_law_system_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Jordan_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Kuwait_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Lebanon_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Libya_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Mauritania_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Mesopotamia_civilization_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Morocco_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Oman_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Palestine_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Qatar_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Saudi_Arabia_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Somalia_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Sudan_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Syria_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Tunisia_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_United_Arab_Emirates_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_Yemen_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_communication_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_computer_and_phone_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_daily_life_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
    "arabic_leaderboard_acva_entertainment_light": f"{BASE_IMPORT}arabic_leaderboard_light:ArabicLeaderboardLightExtractor",
}
